@@ -56,7 +56,7 @@ package Algorithm::Evolutionary::Individual::String;
 use Carp;
 use Exporter;
 
-our ($VERSION) = ( '$Revision: 1.5 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 2.2 $ ' =~ / (\d+\.\d+)/ );
 
 use base 'Algorithm::Evolutionary::Individual::Base';
 
@@ -231,9 +231,9 @@ sub SPLICE {
   my $offset = shift;
   my $length = shift || length( $self->{'_str'} - $offset );
   my $sub_string =  substr( $self->{_str}, $offset, $length );
-  if ( @_ ) {
+#  if ( @_ ) {
     substr( $self->{_str}, $offset, $length ) = join("", @_ );
-  }
+#  } 
   return split(//,$sub_string);
 }
 
@@ -310,10 +310,10 @@ L<Algorithm::Evolutionary::Individual::BitString|Algorithm::Evolutionary::Indivi
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/09/12 18:31:02 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/String.pm,v 1.5 2008/09/12 18:31:02 jmerelo Exp $ 
+  CVS Info: $Date: 2009/03/19 21:13:47 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/String.pm,v 2.2 2009/03/19 21:13:47 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.5 $
+  $Revision: 2.2 $
   $Name $
 
 =cut
