@@ -8,17 +8,14 @@ Algorithm::Evolutionary::Op::Convergence_Terminator  - Checks for termination of
 =head1 SYNOPSIS
 
   my $ct = new Algorithm::Evolutionary::Op::Convergence_Terminator 0.5; 
-  do {
-    $generation->apply($pop_hashref );
-  } until ($ct->apply( $pop_hashref );
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Base>
+L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
-Checks for termination after if population has converged
+    Checks for termination after if population has converged
 
 =head1 METHODS
 
@@ -26,7 +23,7 @@ Checks for termination after if population has converged
 
 package Algorithm::Evolutionary::Op::Convergence_Terminator;
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 2.3 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
@@ -84,10 +81,10 @@ L<Algorithm::Evolutionary::Op::DeltaTerm>.
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Convergence_Terminator.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/16 16:16:40 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/GenerationalTerm.pm,v 2.3 2009/02/16 16:16:40 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 2.3 $
   $Name $
 
 =cut
