@@ -44,10 +44,10 @@ use lib qw( ../.. ../../.. );
 use Algorithm::Evolutionary::Individual::Base;
 
 use Carp;
-our $VERSION = ( '$Revision: 1.1.1.1 $ ' =~ /(\d+\.\d+)/ ) ;
 
+our ($VERSION) = ( '$Revision: 2.3 $ ' =~ / (\d+\.\d+)/ ) ;
 
-=head2 new
+=head2 new( $number_of_individuals, $class_to_generate, $options_hash )
 
 Takes a hash with specific parameters for each subclass, creates the 
 object, and leaves subclass-specific assignments to subclasses
@@ -66,7 +66,7 @@ sub new {
   return $self;
 }
 
-=head2 apply
+=head2 apply( $population_hash )
 
 Generates the population according to the parameters passed in the ctor
 
@@ -82,7 +82,7 @@ sub apply ($) {
   }
 }
 
-=head2 asXML
+=head2 asXML()
 
 Serializes the object as an XML nodeset
 
@@ -104,7 +104,7 @@ EOC
   return $str;
 }  
 
-=head2 set
+=head2 set( $params_hash )
 
 Sets the instance variables of the object, which, so far, should be a 
 bit "raw". Usually called from the base class
@@ -118,8 +118,8 @@ sub set {
   $self->{_number} = $hash->{number};
   $self->{_class} = $hash->{class};
   $self->{_hash} = {};
-  for ( @{$hash->{options}} ) {
-    $self->{_hash}->{$_->{attrib}{name}} = $_->{attrib}{value}
+  for my $k ( keys %{$hash->{options}} ) {
+    $self->{_hash}->{$k} = $hash->{'options'}->{$k};
   }
   
  # } else {
@@ -135,10 +135,10 @@ sub set {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/02/12 17:49:38 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Creator.pm,v 1.1.1.1 2008/02/12 17:49:38 jmerelo Exp $ 
+  CVS Info: $Date: 2009/02/07 18:31:28 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Creator.pm,v 2.3 2009/02/07 18:31:28 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.1.1.1 $
+  $Revision: 2.3 $
   $Name $
 
 =cut
