@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-     Algorithm::Evolutionary::Op::LinearFreezer - used by Simulated Annealing algorithms
+Algorithm::Evolutionary::Op::LinearFreezer - used by Simulated Annealing algorithms, reduces temperature lineally. 
 
 =head1 SYNOPSIS
 
@@ -11,10 +11,6 @@ use warnings;
 
 =head1 Base Class
 
-L< Algorithm::Evolutionary::Op::Base| Algorithm::Evolutionary::Op::Base>
-
-=head1 Base Class
-
 L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 METHODS
@@ -23,7 +19,7 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 package  Algorithm::Evolutionary::Op::LinearFreezer;
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ / (\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 2.2 $ ' =~ / (\d+\.\d+)/ );
 
 use Carp;
 use base 'Algorithm::Evolutionary::Op::Base';
@@ -65,10 +61,10 @@ sub apply ($$) {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/LinearFreezer.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2009/03/24 17:36:00 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/LinearFreezer.pm,v 2.2 2009/03/24 17:36:00 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 2.2 $
   $Name $
 
 =cut
