@@ -1,13 +1,15 @@
 use strict; #-*-cperl-*-
 use warnings;
 
+use lib qw( ../../../../lib );
+
 =head1 NAME
 
-     Algorithm::Evolutionary::Op::RouletteWheel - Fitness-proportional selection, using a roulette wheel
+Algorithm::Evolutionary::Op::RouletteWheel - Fitness-proportional selection, using a roulette wheel
 
 =head1 SYNOPSIS
 
-    use  Algorithm::Evolutionary::Op::RouletteWheel;
+    use Algorithm::Evolutionary::Op::RouletteWheel;
     my $popSize = 100;
     my $selector = new  Algorithm::Evolutionary::Op::RouletteWheel $popSize;
 
@@ -30,7 +32,7 @@ L<http://www.geatbx.com/docu/algselct.html#nameselectionrws|this GA tutorial>
 package  Algorithm::Evolutionary::Op::RouletteWheel;
 use Carp;
 
-our $VERSION = ( '$Revision: 1.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 2.3 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use base 'Algorithm::Evolutionary::Op::Selector';
 
@@ -81,16 +83,20 @@ sub apply (@) {
   return @output;
 }
 
+=head1 See Also
+
+L<Algorithm::Evolutionary::Op::TournamentSelect> is another option for
+selecting a pool of individuals
 
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/07/27 08:31:11 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/RouletteWheel.pm,v 1.2 2008/07/27 08:31:11 jmerelo Exp $ 
+  CVS Info: $Date: 2009/03/24 17:12:52 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/RouletteWheel.pm,v 2.3 2009/03/24 17:12:52 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.2 $
+  $Revision: 2.3 $
   $Name $
 
 =cut
