@@ -1,10 +1,11 @@
 use strict; #-*-cperl-*-
 use warnings;
 
+use lib qw( ../../../../lib );
+
 =head1 NAME
 
-    Algorithm::Evolutionary::Op::TournamentSelect - Tournament selector, takes individuals from one population
-                       and puts them into another
+Algorithm::Evolutionary::Op::TournamentSelect - Tournament selector, takes individuals from one population and puts them into another
 
 =head1 SYNOPSIS
 
@@ -15,7 +16,7 @@ use warnings;
 
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Selector>
+L<Algorithm::Evolutionary::Op::Selector>
 
 =head1 DESCRIPTION
 
@@ -32,7 +33,7 @@ the best.
 package Algorithm::Evolutionary::Op::TournamentSelect;
 use Carp;
 
-our $VERSION = ( '$Revision: 1.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 2.3 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
@@ -79,13 +80,18 @@ sub apply (@) {
   return @output;
 }
 
+=head1 See Also
+
+L<Algorithm::Evolutionary::Op::RouleteWheel> is another option for
+selecting a pool of individuals
+
 =head1 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2008/07/27 08:31:11 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/TournamentSelect.pm,v 1.2 2008/07/27 08:31:11 jmerelo Exp $ 
+  CVS Info: $Date: 2009/03/24 17:12:52 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/TournamentSelect.pm,v 2.3 2009/03/24 17:12:52 jmerelo Exp $ 
   $Author: jmerelo $ 
 
 =cut
