@@ -32,12 +32,13 @@ package Algorithm::Evolutionary::Utils;
 
 use Exporter;
 our @ISA = qw(Exporter);
-our ($VERSION) = ( '$Revision: 2.4 $ ' =~ /(\d+\.\d+)/ ) ;
-our @EXPORT_OK = qw( entropy consensus hamming random_bitstring parse_xml);
+our ($VERSION) = ( '$Revision: 2.6 $ ' =~ /(\d+\.\d+)/ ) ;
+our @EXPORT_OK = qw( entropy consensus hamming random_bitstring average parse_xml);
 
 use Carp;
 use String::Random;
 use XML::Parser;
+use Statistics::Basic qw(mean);
 
 =head2 entropy( $population)
 
@@ -71,15 +72,16 @@ sub hamming {
     return ( ( $string_a ^ $string_b ) =~ tr/\1//);
 }
 
-=head2 consensus( $population )
+=head2 consensus( $population, $rough = 0 )
 
 Consensus sequence representing the majoritary value for each bit;
-returns the consensus string. 
+returns the consensus string. If "rough", then the bit is set only if the difference is bigger than 0.4 (70/30 proportion)
 
 =cut
 
 sub consensus {
   my $population = shift;
+  my $rough = shift;
   my @frequencies;
   for ( @$population ) {
       for ( my $i = 0; $i < $_->size(); $i ++ ) {
@@ -92,15 +94,42 @@ sub consensus {
   }
   my $consensus;
   for my $f ( @frequencies ) {
+    if ( !$rough ) {
       if ( $f->{'0'} > $f->{'1'} ) {
-	  $consensus.='0';
+	$consensus.='0';
       } else {
-	  $consensus.='1';
+	$consensus.='1';
       }
+    } else {
+      my $difference = abs( $f->{'0'} - $f->{'1'} );
+      if ( $difference < 0.4 ) {
+	$consensus .= '-';
+      } else {
+	if ( $f->{'0'} > $f->{'1'} ) {
+	  $consensus.='0';
+	} else {
+	  $consensus.='1';
+	}
+      }
+    }
   }
   return $consensus;
 }
 
+=head2 average( $population )
+
+Computes an average of population fitness
+
+=cut
+
+sub average {
+  my $population = shift;
+  my @frequencies;
+  my @fitnesses = map( $_->Fitness(), @$population );
+  return mean( @fitnesses );
+
+}
+
 =head2 random_bitstring( $bits )
 
 Returns a random bitstring with the stated number of bits. Useful for testing,mainly
@@ -134,10 +163,10 @@ sub parse_xml {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/07 18:31:28 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Utils.pm,v 2.4 2009/02/07 18:31:28 jmerelo Exp $ 
+  CVS Info: $Date: 2009/03/29 09:42:41 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Utils.pm,v 2.6 2009/03/29 09:42:41 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.4 $
+  $Revision: 2.6 $
   $Name $
 
 =cut
